summaryrefslogtreecommitdiff
path: root/libavcodec/wmaprodec.c
diff options
context:
space:
mode:
authorMans Rullgard <mans@mansr.com>2011-03-19 15:14:17 +0000
committerMans Rullgard <mans@mansr.com>2011-03-19 19:49:18 +0000
commit26f548bb59177cfc8c45ff633dd37b60cfd23edf (patch)
tree1e2f6b7d04f8554c60eb4b562844f1cf21b64b9b /libavcodec/wmaprodec.c
parentec10a9ab461b26b96eff7bbbb8623f42d8ee04ad (diff)
fft: remove inline wrappers for function pointers
This removes the rather pointless wrappers (one not even inline) for calling the fft_calc and related function pointers. Signed-off-by: Mans Rullgard <mans@mansr.com>
Diffstat (limited to 'libavcodec/wmaprodec.c')
-rw-r--r--libavcodec/wmaprodec.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/libavcodec/wmaprodec.c b/libavcodec/wmaprodec.c
index 242139d569..343ac84d9b 100644
--- a/libavcodec/wmaprodec.c
+++ b/libavcodec/wmaprodec.c
@@ -1222,6 +1222,7 @@ static int decode_subframe(WMAProDecodeCtx *s)
get_bits_count(&s->gb) - s->subframe_offset);
if (transmit_coeffs) {
+ FFTContext *mdct = &s->mdct_ctx[av_log2(subframe_len) - WMAPRO_BLOCK_MIN_BITS];
/** reconstruct the per channel data */
inverse_channel_transform(s);
for (i = 0; i < s->channels_for_cur_subframe; i++) {
@@ -1246,9 +1247,8 @@ static int decode_subframe(WMAProDecodeCtx *s)
quant, end - start);
}
- /** apply imdct (ff_imdct_half == DCTIV with reverse) */
- ff_imdct_half(&s->mdct_ctx[av_log2(subframe_len) - WMAPRO_BLOCK_MIN_BITS],
- s->channel[c].coeffs, s->tmp);
+ /** apply imdct (imdct_half == DCTIV with reverse) */
+ mdct->imdct_half(mdct, s->channel[c].coeffs, s->tmp);
}
}